Value Errors
------------

.. currentmodule:: pyhmmer.errors

.. autoexception:: AlphabetMismatch(ValueError)
   :special-members: __init__
   :members:

.. autoexception:: MissingCutoffs(ValueError)
   :special-members: __init__
   :members:

.. autoexception:: InvalidHMM(ValueError)
   :special-members: __init__
   :members:

.. autoexception:: InvalidParameter(ValueError)
   :special-members: __init__
   :members:
